==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Categorie");
define("_LVOTES","Stemmen");
define("_HITS","Hits:");
define("_TOPWELCOME","Welkom op de TOP pagina van ");
define("_READSTORIES","vaakst gelezen verhalen");
define("_COMMENTEDSTORIES","vaakst gecommenteerde verhalen");
define("_ACTIVECAT","meest actieve categorien");
define("_READSECTION","vaakst gelezen artikelen in speciale secties");
define("_NEWSSUBMITTERS","meest actieve nieuws-inzenders");
define("_NEWSSENT","nieuws ingezonden");
define("_VOTEDPOLLS","vaakst gestemde peilingen");
define("_MOSTACTIVEAUTHORS","vaakst actieve auteurs");
define("_NEWSPUBLISHED","nieuws gepubliceerd");
define("_READREVIEWS","vaakst gelezen recensies");
define("_DOWNLOADEDFILES","vaakst gedownloade bestanden");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Categorie");
define("_LVOTES","Stemmen");
define("_HITS","Hits:");
define("_TOPWELCOME","Welkom op de TOP pagina van ");
define("_READSTORIES","vaakst gelezen verhalen");
define("_COMMENTEDSTORIES","vaakst gecommenteerde verhalen");
define("_ACTIVECAT","meest actieve categorien");
define("_READSECTION","vaakst gelezen artikelen in speciale secties");
define("_NEWSSUBMITTERS","meest actieve nieuws-inzenders");
define("_NEWSSENT","nieuws ingezonden");
define("_VOTEDPOLLS","vaakst gestemde peilingen");
define("_MOSTACTIVEAUTHORS","vaakst actieve auteurs");
define("_NEWSPUBLISHED","nieuws gepubliceerd");
define("_READREVIEWS","vaakst gelezen recensies");
define("_DOWNLOADEDFILES","vaakst gedownloade bestanden");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
